==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_DO.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Loading accounts" : "Cargando cuentas",
    "Error while loading the accounts." : "Se presentó un error al cargar las cuentas.",
    "Can not load this folder." : "No se puede cargar esta carpeta.",
    "Searching for {query}" : "Buscando a {query}",
    "Error while deleting message." : "Se presentó un error al borrar el mensaje.",
    "Forwarded message" : "mensaje reenviado",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Attachments saved to Files." : "Adjuntos guardados a Archivos. ",
    "Attachment saved to Files." : "Adjunto guardado en Archivos. ",
    "Error while saving attachments to Files." : "Se presentó un error al guardar los adjuntos en Archivos.",
    "Error while saving attachment to Files." : "Se presentó un error al guardar los adjuntos en Archivos",
    "Message flag could not be set." : "No fue posible establecer la bandera del mensaje. ",
    "Could not move message." : "No fue posible mover el mensaje.",
    "Invalid account" : "Cuenta inválida",
    "Invalid folder" : "Carpeta inválida",
    "Error while creating the account: " : "Se presentó un error al crear la cuenta:",
    "Unknown error" : "Error desconocido",
    "Error while updating the account: " : "Se presentó un error al actualizar la cuenta:",
    "All inboxes" : "Todos los buzones de entrada",
    "you" : "tú",
    "Send message to {email}" : "Enviar mensaje a {email}",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "Save" : "Guardar",
    "Saved" : "Guardado",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Error while deleting account." : "Se presetó un error al borrar la cuenta.",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "An error occurred while uploading {fname}" : "Se presentó un error durante la carga {fname}",
    "Reply" : "Responder",
    "Send" : "Enviar",
    "Sending …" : "Enviando ...",
    "Message sent!" : "¡Mensaje enviado!",
    "Server error" : "Se presentó un error en el servidor",
    "An unknown error occurred" : "Se presentó un error desconocido",
    "Opening HTML drafts is not supported yet." : "Abrir borradores HTML aún no está soportado.",
    "No writable calendars found" : "No se encontraron calendarios editables",
    "Error while importing the calendar event" : "Se presentó un error al importar el evento del calendario",
    "Error while downloading calendar event" : "Se presentó un error al descargar el evento del calendario",
    "& others" : "& otros",
    "Error while loading messages." : "Se presentói un error al cargar los mensajes.",
    "Error while refreshing messages." : "Se presentó un error al actualizar los mensajes.",
    "Setting up your account" : "Configura tu cuenta",
    "Inbox" : "Buzón de entrada",
    "Sent" : "Enviado",
    "Drafts" : "Borradores",
    "Archive" : "Archivar",
    "Trash" : "Basura",
    "Junk" : "Basura",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
    "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Delete permanently" : "Borrar permanentemente",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Settings" : "Configuraciones ",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no quieres visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s",
    "Delete account" : "Borrar cuenta",
    "Try again" : "Reintentar",
    "New message" : "Mensaje nuevo",
    "Account Settings" : "Configuraciones  de la cuenta",
    "Aliases" : "Aliases",
    "Mail address" : "Dirección de correo",
    "Display Name" : "Nombre a desplegar",
    "Account" : "Cuenta",
    "Delete" : "Borrar",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Search" : "Buscar",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "Manual configuration" : "Configuración manual",
    "IMAP Host" : "Servidor IMAP",
    "IMAP security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connect" : "Conectar",
    "from" : "de",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "cco",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota que el correo vino de una dirección no-responda asi que tu respuesta probablemente no sea leida. ",
    "Subject" : "Asunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "No search results for" : "No se obtuvieron resultados para la búsqueda de ",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Show images from this sender" : "Mostrar imagenes de este remitente",
    "Forward" : "Reenviar",
    "No messages in this folder" : "No hay mensajes en esta carpeta",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.17.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/es_DO.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Correo",
    "Inbox" : "Buzón de entrada",
    "Sent" : "Enviado",
    "Drafts" : "Borradores",
    "Archive" : "Archivar",
    "Trash" : "Basura",
    "Junk" : "Basura",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
    "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
    "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
    "Delete permanently" : "Borrar permanentemente",
    "Name" : "Nombre",
    "Mail Address" : "Dirección de Correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Connect" : "Conectar",
    "Add mail account" : "Agregar cuenta de correo",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Keyboard shortcuts" : "Atajos del teclado",
    "from" : "de",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "cco",
    "Subject" : "Asunto",
    "Sending …" : "Enviando ...",
    "Message sent!" : "¡Mensaje enviado!",
    "Send" : "Enviar",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "No messages in this folder" : "No hay mensajes en esta carpeta",
    "Delete" : "Borrar",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Save all to Files" : "Guardar todo a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "New message" : "Mensaje nuevo",
    "Settings" : "Configuraciones ",
    "Show all folders" : "Mostrar todas las carpetas",
    "Collapse folders" : "Compactar carpetas",
    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Search" : "Buscar",
    "Refresh" : "Actualizar",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "All inboxes" : "Todos los buzones de entrada",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no quieres visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=2; plural=(n != 1);");
